@@ -86,7 +86,7 @@ class Rocket():
 
     def __init__(self, launchpad, fworker, fw_id):
         """
-        
+
         :param launchpad: (LaunchPad) A LaunchPad object for interacting with the FW database. If none, reads FireWorks from FW.json and writes to FWAction.json
         :param fworker: (FWorker) A FWorker object describing the computing resource
         :param fw_id: (int) id of a specific FireWork to run (quit if it cannot be found)
@@ -95,7 +95,6 @@ class Rocket():
         self.fworker = fworker
         self.fw_id = fw_id
 
-
     def run(self):
         """
         Run the rocket (check out a job from the database and execute it)
@@ -141,6 +140,9 @@ class Rocket():
                 except:
                     pass
 
+        if lp:
+            lp.m_logger.info('RUNNING fw_id: {} in directory: {}'.format(m_fw.fw_id, os.getcwd()))
+
         # write FW.json and/or FW.yaml to the directory
         if PRINT_FW_JSON:
             m_fw.to_file('FW.json', indent=4)
@@ -149,6 +151,7 @@ class Rocket():
 
         try:
             my_spec = dict(m_fw.spec)  # make a copy of spec, don't override original
+            my_spec["_fw_env"] = self.fworker.env
 
             # set up heartbeat (pinging the server that we're still alive)
             ping_stop = start_ping_launch(lp, launch_id)
